---
 src/gallium/drivers/swr/rasterizer/core/backend.h |  1 +
 src/gallium/drivers/swr/rasterizer/core/state.h   | 10 +++++-----
 2 files changed, 6 insertions(+), 5 deletions(-)

diff --git a/src/gallium/drivers/swr/rasterizer/core/backend.h 
b/src/gallium/drivers/swr/rasterizer/core/backend.h
index 7bb1f55..dba5041 100644
--- a/src/gallium/drivers/swr/rasterizer/core/backend.h
+++ b/src/gallium/drivers/swr/rasterizer/core/backend.h
@@ -499,6 +499,7 @@ void SetupPixelShaderContext(SWR_PS_CONTEXT *psContext, 
const SWR_MULTISAMPLE_PO
     psContext->pPerspAttribs = work.pPerspAttribs;
     psContext->frontFace = work.triFlags.frontFacing;
     psContext->primID = work.triFlags.primID;
+    psContext->renderTargetArrayIndex = work.triFlags.renderTargetArrayIndex;
 
     // save Ia/Ib/Ic and Ja/Jb/Jc if we need to reevaluate i/j/k in the shader 
because of pull attribs
     psContext->I = work.I;
diff --git a/src/gallium/drivers/swr/rasterizer/core/state.h 
b/src/gallium/drivers/swr/rasterizer/core/state.h
index 8812fba..75d1210 100644
--- a/src/gallium/drivers/swr/rasterizer/core/state.h
+++ b/src/gallium/drivers/swr/rasterizer/core/state.h
@@ -342,11 +342,11 @@ struct SWR_PS_CONTEXT
     simdvector shaded[SWR_NUM_RENDERTARGETS];
                                 // OUT: result color per rendertarget
 
-    uint32_t frontFace;         // IN: front- 1, back- 0
-    uint32_t primID;            // IN: primitive ID
-    uint32_t sampleIndex;       // IN: sampleIndex
-
-    uint32_t rasterizerSampleCount; // IN: sample count used by the rasterizer
+    uint32_t frontFace;                 // IN: front- 1, back- 0
+    uint32_t primID;                    // IN: primitive ID
+    uint32_t sampleIndex;               // IN: sampleIndex
+    uint32_t renderTargetArrayIndex;    // IN: render target array index from 
GS
+    uint32_t rasterizerSampleCount;     // IN: sample count used by the 
rasterizer
 
     uint8_t* pColorBuffer[SWR_NUM_RENDERTARGETS]; // IN: Pointers to render 
target hottiles
 };
-- 
2.7.4

_______________________________________________
mesa-dev mailing list
mesa-dev@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/mesa-dev

Reply via email to